==> zio-aws-chimesdkmessaging_2.13-5.17.126.2-sources.jar: zio/aws/chimesdkmessaging/model/GetChannelMessageStatusResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetChannelMessageStatusResponse(
    status: Option[
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse = {
    import GetChannelMessageStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
      .builder()
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse
      .wrap(buildAwsValue())
}
object GetChannelMessageStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse =
      zio.aws.chimesdkmessaging.model
        .GetChannelMessageStatusResponse(status.map(value => value.asEditable))
    def status: Option[
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure.ReadOnly
    ]
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure.ReadOnly
    ] = AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
  ) extends zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse.ReadOnly {
    override val status: Option[
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure.ReadOnly
    ] = scala
      .Option(impl.status())
      .map(value =>
        zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
  ): zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-chimesdkmessaging_2.13-5.17.195.2-sources.jar: zio/aws/chimesdkmessaging/model/GetChannelMessageStatusResponse.scala <==
package zio.aws.chimesdkmessaging.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetChannelMessageStatusResponse(
    status: Optional[
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse = {
    import GetChannelMessageStatusResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
      .builder()
      .optionallyWith(status.map(value => value.buildAwsValue()))(_.status)
      .build()
  }
  def asReadOnly
      : zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse.ReadOnly =
    zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse
      .wrap(buildAwsValue())
}
object GetChannelMessageStatusResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse =
      zio.aws.chimesdkmessaging.model
        .GetChannelMessageStatusResponse(status.map(value => value.asEditable))
    def status: Optional[
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure.ReadOnly
    ]
    def getStatus: ZIO[
      Any,
      AwsError,
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure.ReadOnly
    ] = AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
  ) extends zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse.ReadOnly {
    override val status: Optional[
      zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.status())
      .map(value =>
        zio.aws.chimesdkmessaging.model.ChannelMessageStatusStructure
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.chimesdkmessaging.model.GetChannelMessageStatusResponse
  ): zio.aws.chimesdkmessaging.model.GetChannelMessageStatusResponse.ReadOnly =
    new Wrapper(impl)
}
